@@ -1,7 +1,7 @@
 package Complete::Bash;
 
-our $DATE = '2019-07-02'; # DATE
-our $VERSION = '0.327'; # VERSION
+our $DATE = '2019-07-30'; # DATE
+our $VERSION = '0.328'; # VERSION
 
 use 5.010001;
 use strict;
@@ -400,7 +400,7 @@ sub join_wordbreak_words {
 sub _terminal_width {
     # XXX need to cache?
     if (eval { require Term::Size; 1 }) {
-        my ($cols, undef) = Term::Size::chars();
+        my ($cols, undef) = Term::Size::chars(*STDOUT{IO});
         $cols;
     } else {
         $ENV{COLUMNS} // 80;
@@ -755,7 +755,7 @@ Complete::Bash - Completion routines for bash shell
 
 =head1 VERSION
 
-This document describes version 0.327 of Complete::Bash (from Perl distribution Complete-Bash), released on 2019-07-02.
+This document describes version 0.328 of Complete::Bash (from Perl distribution Complete-Bash), released on 2019-07-30.
 
 =head1 DESCRIPTION
 
